pub struct Diff {
pub changed: Vec<PathBuf>,
pub deleted: Vec<PathBuf>,
}Expand description
Result of DepGraph::diff.
Fields
changed: Vec<PathBuf>Sources whose SHA-256 changed since the cached graph, or new sources without a cached hash.
deleted: Vec<PathBuf>Sources tracked by the cached graph that no longer exist on disk.
Implementations